require File.dirname(__FILE__) + '/../spec_helper'

describe Useless::Museum::Image do
  def image(path = nil)
    @instance ||= begin
      file = File.open asset_path(path || 'muffin-milk.jpg')
      Useless::Museum::Image.new(file)
    end
  end

  def assert_image_resize(image, length)
    if image[:width] > image[:height]
      image[:width].should == length
    elsif image[:height] > image[:width]
      image[:height].should == length
    else
      image[:width].should == length and image[:height].should == length
    end
  end

  describe '#small' do
    it 'should return a MiniMagick::Image object whose longest dimension is 100 pixels' do
      small_image = image.small
      small_image.should be_a(MiniMagick::Image)
      assert_image_resize small_image, 100
    end
  end

  describe '#medium' do
    it 'should return a MiniMagick::Image object whose longest dimension is 500 pixels' do
      medium_image = image.medium
      medium_image.should be_a(MiniMagick::Image)
      assert_image_resize medium_image, 500
    end
  end

  describe '#large' do
    it 'should return a MiniMagick::Image object whose longest dimension is 1024 pixels' do
      large_image = image.large
      large_image.should be_a(MiniMagick::Image)
      assert_image_resize large_image, 1024
    end
  end

  # These specs aren't particularly useful as you have to go on faith that
  # muffin-milk.jpg actually has these values embedded - I guess these can act
  # as a sanity check
  describe '#latitude' do
    it 'should return the latitude value exracted from the image' do
      image.latitude.to_i.should == 40
    end

    it 'should return nil if the image has no metadata' do
      image('muffin-milk-stripped.jpg').latitude.should be_nil
    end
  end

  describe '#longitude' do
    it 'should return the latitude value exracted from the image' do
      image.longitude.to_i.should == -73
    end

    it 'should return nil if the image has no metadata' do
      image('muffin-milk-stripped.jpg').longitude.should be_nil
    end
  end

  describe '#shot_at' do
    it 'shoulr return the time that the image was taken' do
      image.shot_at.should == Time.parse('2011-11-14T02:23:42Z')
    end

    it 'should return nil if the image has no metadata' do
      image('muffin-milk-stripped.jpg').shot_at.should be_nil
    end
  end

  describe '#valid?' do
    it 'should return true if the image is a JPEG' do
      image('muffin-milk.jpg').should be_valid
    end

    it 'should return true if the image is a PNG' do
      image('muffin-milk.png').should be_valid
    end

    it 'should return true if the image is a TIFF' do
      image('muffin-milk.tiff').should be_valid
    end

    it 'should return true if the image is a GIF' do
      image('muffin-milk.gif').should be_valid
    end
  end
end
